.. _spkg_modular_decomposition:

modular_decomposition: A modular decomposition algorithm
==================================================================

Description
-----------

This is an implementation of a modular decomposition algorithm.

http://www.liafa.jussieu.fr/~fm/ (in french)

License
-------

GPL


Upstream Contact
----------------

Fabien de Montgolfier

http://www.liafa.jussieu.fr/~fm/


Type
----

experimental


Dependencies
------------


Version Information
-------------------

package-version.txt::

    20100607


Equivalent System Packages
--------------------------


See https://repology.org/project/modular-decomposition/versions

However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.

